@@ -4,11 +4,14 @@ from pathlib import Path
 
 class FileWatcher:
 
-    def __init__( self, file_path: Path ):
+    def __init__( self, file_path: Path, record_now = True ):
         self.file_path = file_path
-        self.last_seen_time_modified = None
+        if record_now:
+            self.last_seen_time_modified = self.get_last_time_modified()
+        else:
+            self.last_seen_time_modified = 0
 
-    def get_last_time_modified( self ):
+    def get_last_time_modified( self ) -> float:
         return os.path.getmtime( self.file_path )
 
     def is_file_updated( self ) -> bool:
